FzPattern class

Strict Pattern Symbol ^ and $ in pattern is to make sure all the string value following the pattern Regex will return false if any of the characters do not follow the pattern. Example: Email Pattern

Constructors

FzPattern()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

canadaPostalCodeValidator → RegExp
Matches Canada Postal Code Validation
final
internationalPhoneNumValidator → RegExp
Matches International Phone Numbers
final
ninValidator → RegExp
Matches national insurance numbers in the UK
final
postCodeValidator → RegExp
Matches UK post codes
final
ssnValidator → RegExp
Matches SSN Number
final
uszipcodeValidator → RegExp
Matches US Zip Code Validation
final

Constants

aadhaar → const Pattern
Aadhaar (UIDAI 12-digit number) Format: 12 digits, cannot start with 0 or 1 Example: 234567890123
alphabetOnly → const Pattern
Alphabet Only regex (No Whitespace & Symbols)
apk → const Pattern
APK regex
audio → const Pattern
Audio regex
base64 → const Pattern
Base64 String Regex Examples: SGVsbG8gd29ybGQ=, U29tZSBzdHJpbmc=
basicDateTime → const Pattern
DateTime regex (UTC) Unformatted date time (UTC and Iso8601) Example: 2020-04-27 08:14:39.977, 2020-04-27T08:14:39.977, 2020-04-27 01:14:39.977Z
binanceSmartChainAddress → const Pattern
Binance Chain (BEP-20) Address Regex (Same as Ethereum) Examples: 0x28C6c06298d514Db089934071355E5743bf21d60
binary → const Pattern
Binary regex Consist only 0 & 1
bip39Mnemonic → const Pattern
BIP39 Mnemonic Regex (12 or 24 words) Examples: legal winner thank year wave sausage worth useful legal winner thank yellow abandon abandon abandon abandon abandon abandon abandon abandon abandon abandon abandon about
bitcoinAddress → const Pattern
Bitcoin Address Regex (Legacy & SegWit) Examples: 1BoatSLRHtKNngkdXEeobR76b53LETtpyT, 3J98t1WpEZ73CNmQviecrnyiWrnqRhWNLy
cardanoAddress → const Pattern
Cardano Shelley Address Regex (starts with addr1) Examples: addr1q9z06azdku5f8u20szctwegrv08c7l5psxx4c83n0nq3qkdjqw7zzg8v4ga2q9q8rpgz2c6x0nnpag6t0jx9cq4tgf6qg0ahz3
colorHexWithAlpha → const Pattern
Color Code (Hex with optional alpha) Regex Examples: #FFF, #FFFFFF, #FFFFFFFF, #1234
creditcard → const Pattern
Credit/Debit Card
currency → const Pattern
Currency regex
dashAddress → const Pattern
Dash Address Regex Examples: XwnLY9Tf7Zsef8gMGL2fhWA9ZmMjt4KPwg
doc → const Pattern
Document regex
dogecoinAddress → const Pattern
Dogecoin Address Regex Examples: D5r2hrU1qJUzS9NBpZxkA6sZs6kKjA3vZc
email → const Pattern
Email regex
emoji → const Pattern
Emoji Regex (basic support for common emojis) Examples: 😀, ❤️, 🚀
ethereumAddress → const Pattern
Ethereum Address Regex Examples: 0xde0B295669a9FD93d5F28D9Ec85E40f4cb697BAe
excel → const Pattern
Excel regex
firebasePushId → const Pattern
Firebase Push ID Regex Example: -MabcdEfghIJKlmNoPqR
github → const Pattern
Github repository regex
gstin → const Pattern
GSTIN (Goods and Services Tax Identification Number) - 15 characters Format: 2 digit state code + 10-digit PAN + 1 entity code + 1 checksum Example: 22AAAAA0000A1Z5
hexadecimal → const Pattern
Hexadecimal regex
html → const Pattern
HTML regex
htmlTags → const Pattern
HTML Tags multiLine = true
iban → const Pattern
IBAN (International Bank Account Number) Supports general IBAN structure: 2 letters country code + 2 digits + up to 30 alphanumeric chars Example: GB82WEST12345698765432
ifsc → const Pattern
IFSC Code - 11 characters Format: 4 letters (bank code) + 0 + 6-digit branch code Example: SBIN0005943
image → const Pattern
Image regex
ipv4 → const Pattern
IPv4 regex
ipv4Cidr → const Pattern
IPv4 CIDR Notation Regex Examples: 192.168.1.0/24, 10.0.0.0/8
ipv6 → const Pattern
IPv6 regex
isbn → const Pattern
ISBN 10 & 13 regex
litecoinAddress → const Pattern
Litecoin Address Regex Examples: LZym3j8fS9bWf8o6RzKvA3tC2AedZ6W9aW
macAddress → const Pattern
MAC Address Regex Examples: 00:1A:2B:3C:4D:5E, 00-1A-2B-3C-4D-5E
md5 → const Pattern
MD5 regex
moneroAddress → const Pattern
Monero Address Regex Examples: 48bWuoDGAGY4o9c8ZC2XG3dQtrM7StJmqAsYHgw4x9qV6uW6t7P1AJVC3fUQ7m7G3yyMfA8GJmLt4zHYvstDQCQL6j9e9sS
name → const Pattern
Name regex
numericOnly → const Pattern
Numeric Only regex (No Whitespace & Symbols)
onlynumber → const Pattern
Only Numbers
pan → const Pattern
PAN (Permanent Account Number) - 10 characters Format: 5 letters + 4 digits + 1 letter Example: ABCDE1234F
passport → const Pattern
Passport No. regex
passwordEasy → const Pattern
Password (Easy) Regex Allowing all character except 'whitespace' Minimum character: 8
passwordEasyAllowedWhitespace → const Pattern
Password (Easy) Regex Allowing all character Minimum character: 8
passwordHard → const Pattern
Password (Hard) Regex Allowing all character except 'whitespace' Must contains at least: 1 uppercase letter, 1 lowecase letter, 1 number, & 1 special character (symbol) Minimum character: 8
passwordHardAllowedWhitespace → const Pattern
Password (Hard) Regex Allowing all character Must contains at least: 1 uppercase letter, 1 lowecase letter, 1 number, & 1 special character (symbol) Minimum character: 8
passwordNormal1 → const Pattern
Password (Normal) Regex Allowing all character except 'whitespace' Must contains at least: 1 letter & 1 number Minimum character: 8
passwordNormal1AllowedWhitespace → const Pattern
Password (Normal) Regex Allowing all character Must contains at least: 1 letter & 1 number Minimum character: 8
passwordNormal2 → const Pattern
Password (Normal) Regex Allowing LETTER and NUMBER only Must contains at least: 1 letter & 1 number Minimum character: 8
passwordNormal2AllowedWhitespace → const Pattern
Password (Normal) Regex Allowing LETTER and NUMBER only Must contains: 1 letter & 1 number Minimum character: 8
passwordNormal3 → const Pattern
Password (Normal) Regex Allowing all character except 'whitespace' Must contains at least: 1 uppercase letter, 1 lowecase letter & 1 number Minimum character: 8
passwordNormal3AllowedWhitespace → const Pattern
Password (Normal) Regex Allowing all character Must contains at least: 1 uppercase letter, 1 lowecase letter & 1 number Minimum character: 8
pdf → const Pattern
PDF regex
phone → const Pattern
Phone Number regex Must started by either, "0", "+", "+XX <X between 2 to 4 digit>", "(+XX <X between 2 to 3 digit>)" Can add whitespace separating digit with "+" or "(+XX)" Example: 05555555555, +555 5555555555, (+123) 5555555555, (555) 5555555555, +5555 5555555555
polkadotAddress → const Pattern
Polkadot Address Regex Examples: 12D3KooWM1rCZU4vT2LuXoYgB1T6PqvpmGJv8SBrC7oQQXvQUgZq
postalCode → const Pattern
Postal Code
ppt → const Pattern
PPT regex
privateKeyHex → const Pattern
Private Key (Ethereum-like 64 hex chars) Examples: 4c0883a69102937d6231471b5dbb6204fe51296170827946d27b382e66ad4f4f
rippleAddress → const Pattern
Ripple (XRP) Address Regex Examples: rG1QQv2nh2gr7RCZ1P8YYcBUKCCN633jCn
sha1 → const Pattern
SHA1 regex
sha256 → const Pattern
SHA256 regex
slug → const Pattern
Slug (URL-friendly string) Regex Examples: hello-world, flutter-tutorial, my-blog-post
solanaAddress → const Pattern
Solana Address Regex Examples: 4Nd1mYzGQj6PPZQZn5hVQ5AYy6AS2FoKZ5FBL2XRxYcB
ssn → const Pattern
SSN (Social Security Number) regex
time12 → const Pattern
Time (12-hour format with AM/PM) Regex Examples: 1:45 PM, 12:00 am, 09:15 Am
time24 → const Pattern
Time (24-hour format) Regex Examples: 23:59, 00:00, 14:30
transactionHash → const Pattern
Transaction Hash (64 hex characters) Examples: 0x5e2d3c57c0e58923a948e8cd5a1a8d5f50f5a5caa1bcf7d8a1de474f21f7915a
tronAddress → const Pattern
Tron Address Regex Examples: TQ5xAinUM2BV5EUD5L5EwbBeH6RBaJv1io
twitterUsername → const Pattern
Twitter Username Regex Examples: @username, username
txt → const Pattern
Txt regex
upiId → const Pattern
UPI ID Regex (e.g. mobile@upi or username@bank) Accepts lowercase, digits, dot, dash, plus underscore in name; domain must be alphanumeric Examples: test.user@okaxis, 1234567890@upi
url → const Pattern
URL regex
username → const Pattern
Username regex
usSsnStrict → const Pattern
US SSN (Social Security Number) - Strict format: XXX-XX-XXXX Invalid prefixes like 000, 666, and 900–999 are not allowed Example: 123-45-6789
uuidV4 → const Pattern
UUID v4 Regex Example: f47ac10b-58cc-4372-a567-0e02b2c3d479
vector → const Pattern
Image vector regex
video → const Pattern
Video regex
youtubeUrl → const Pattern
YouTube Video URL Regex Examples: https://youtu.be/dQw4w9WgXcQ, https://www.youtube.com/watch?v=dQw4w9WgXcQ